#!/bin/sh

# Replace the placeholders in prometheus.yml with the real server name
# we want to use when making SSL requests to controllers, as well as other
# variables.
sed -i"" -e "s/\$TLS_SERVER_NAME/$TLS_SERVER_NAME/g" /etc/prometheus/prometheus.yml
sed -i"" -e "s/\$SCRAPE_INTERVAL/$SCRAPE_INTERVAL/g" /etc/prometheus/prometheus.yml

args=''
while [[ $# -gt 0 ]]
do
    arg="$1"
    case $arg in
        -web.listen-address)
            addr="$2"
            shift
            ;;
        *)
            args="$args $arg"
            ;;
    esac
    shift
done

PROXY_PID=
PROMETHEUS_PID=

# If either the proxy or prometheus servers die, we should kill the other and
# exit.
childHandler() {
    if kill -0 $PROXY_PID; then
        # The proxy is still alive; kill it.
        kill -9 $PROXY_PID
    fi
    if kill -0 $PROMETHEUS_PID; then
        # Prometheus is still alive; kill it.
        kill -9 $PROMETHEUS_PID
    fi
}

trap childHandler CHLD

/bin/proxy "$addr" &
PROXY_PID=$!

echo "started proxy server with PID $PROXY_PID"

/bin/prometheus $args &
PROMETHEUS_PID=$!

echo "started prometheus server with PID $PROMETHEUS_PID"

# Wait for both the proxy and prometheus servers to exit.
wait $PROXY_PID $PROMETHEUS_PID

